@@ -13,7 +13,7 @@ setClass('lcMethodAkmedoids', contains = 'lcMatrixMethod')
 #' @export
 #' @title Specify AKMedoids method
 #' @inheritParams lcMatrixMethod-class
-#' @inheritParams lcMethodCustom
+#' @inheritParams lcMethodFunction
 #' @inheritParams lcMethodKML
 #' @param clusterCenter A function for computing the cluster center representation.
 #' @param crit Criterion to apply for internal model selection. Not applicable.
@@ -80,19 +80,20 @@ setMethod('fit', signature('lcMethodAkmedoids'), function(method, data, envir, v
   clusNames = make.clusterNames(method$nClusters)
 
   trajAssignments = model$solutions[[1]]
-  assert_that(length(trajAssignments) > 0, msg = 'no membership output returned')
+  assert_that(length(trajAssignments) > 0, msg = 'akmedoids package returned an unexpected result: no membership output returned')
 
-  lcModelCustom(
+  lcModelPartition(
     data,
-    trajectoryAssignments = factor(trajAssignments,
+    trajectoryAssignments = factor(
+      trajAssignments,
       levels = LETTERS[1:method$nClusters],
-      labels = clusNames),
-    clusterTrajectories = method$clusterCenter,
+      labels = clusNames
+    ),
+    center = method$clusterCenter,
     response = responseVariable(method),
     time = timeVariable(method),
     id = idVariable(method),
     clusterNames = clusNames,
-    converged = TRUE,
     method = method,
     model = model,
     name = 'akmedoids'
