@@ -25,18 +25,18 @@ setMethod('prepareData', signature('lcMatrixMethod'), function(method, data, ver
 
   e$times = sort(unique(data[[timeColumn]]))
 
-  # Check data
-  assert_that(uniqueN(data[, .N, by = c(idColumn)]$N) == 1, msg = 'not all time series are of equal length')
-
   # Data
   cat(
     verbose,
     'Transforming data to aligned repeated measures matrix format...',
     level = verboseLevels$fine
   )
-  e$dataMat = dcastRepeatedMeasures(data,
-                                    id = idColumn,
-                                    time = timeColumn,
-                                    response = valueColumn)
-  return(e)
+  e$dataMat = tsmatrix(
+    data,
+    id = idColumn,
+    time = timeColumn,
+    response = valueColumn
+  )
+
+  e
 })
